typedef struct {
	Xv_opaque	spec_popup;
	Xv_opaque	control_spec;
	Xv_opaque	spec_message1;
	Xv_opaque	spec1d_list;
	Xv_opaque	spec1d_b1;
	Xv_opaque	spec1d_b2;
	Xv_opaque	spec1d_bn;
	Xv_opaque	spec1d_b3;
	Xv_opaque	spec1d_b4;
	Xv_opaque	spec1d_baction;
	Xv_opaque	spec_clearall_but;
	Xv_opaque	spec_message2;
	Xv_opaque	spec2d_list;
	Xv_opaque	spec2d_b1;
	Xv_opaque	spec2d_bn;
	Xv_opaque	spec2d_b2;
	Xv_opaque	spec2d_b3;
	Xv_opaque	spec2d_b4;
	Xv_opaque	spec2d_b5;
	Xv_opaque	spec2d_b6;
} sort_gui_spec_popup_objects;

sort_gui_spec_popup_objects *sort_gui_spec_popup_objects_initialize
    P((sort_gui_spec_popup_objects * , Xv_opaque));

extern sort_gui_spec_popup_objects *sort_gui_spec_popup;

int list_reset P((Xv_opaque, Xv_opaque *, int));
void spec_popup_spec1d_list_reset P((char **));

#define LIST_FIRST 1
#define LIST_END 1
